Index: trunk/src/org/openstreetmap/josm/actions/OpenFileAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/OpenFileAction.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/actions/OpenFileAction.java	(revision 12894)
@@ -337,5 +337,5 @@
                 fileHistory.removeAll(failedAll);
                 int maxsize = Math.max(0, Config.getPref().getInt("file-open.history.max-size", 15));
-                PreferencesUtils.putCollectionBounded(Config.getPref(), "file-open.history", maxsize, fileHistory);
+                PreferencesUtils.putListBounded(Config.getPref(), "file-open.history", maxsize, new ArrayList<>(fileHistory));
             }
         }
Index: trunk/src/org/openstreetmap/josm/actions/SaveActionBase.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/SaveActionBase.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/actions/SaveActionBase.java	(revision 12894)
@@ -236,5 +236,5 @@
         history.remove(filepath);
         history.add(0, filepath);
-        PreferencesUtils.putCollectionBounded(Config.getPref(), "file-open.history", maxsize, history);
+        PreferencesUtils.putListBounded(Config.getPref(), "file-open.history", maxsize, history);
     }
 }
Index: trunk/src/org/openstreetmap/josm/data/Preferences.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/Preferences.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/data/Preferences.java	(revision 12894)
@@ -1078,5 +1078,5 @@
      * @param def The default value
      * @return The integer value or the default value if it could not be parsed
-     * @deprecated use {@link PreferencesUtils#getInteger(IPreferences, String, String, int)
+     * @deprecated use {@link PreferencesUtils#getInteger(IPreferences, String, String, int)}
      */
     @Deprecated
@@ -1126,5 +1126,5 @@
      * @param value The value that should be removed in the collection
      * @see #getList(String)
-     * @deprecated use {@link PreferencesUtils#removeFromCollection(IPreferences, String, String)}
+     * @deprecated use {@link PreferencesUtils#removeFromList(IPreferences, String, String)}
      */
     @Deprecated
@@ -1236,5 +1236,5 @@
      * @param val value
      * @return {@code true}, if something has changed (i.e. value is different than before)
-     * @deprecated use {@link PreferencesUtils#putCollectionBounded(IPreferences, String, int, Collection)}
+     * @deprecated use {@link PreferencesUtils#putListBounded(IPreferences, String, int, List)}
      */
     @Deprecated
Index: trunk/src/org/openstreetmap/josm/io/UploadStrategy.java
===================================================================
--- trunk/src/org/openstreetmap/josm/io/UploadStrategy.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/io/UploadStrategy.java	(revision 12894)
@@ -85,5 +85,5 @@
             v = Config.getPref().get("osm-server.atomic-upload", null);
             if (v != null) {
-                PreferencesUtils.removeFromCollection(Config.getPref(), "osm-server.atomic-upload", v);
+                PreferencesUtils.removeFromList(Config.getPref(), "osm-server.atomic-upload", v);
             } else {
                 v = "";
Index: trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 12894)
@@ -349,5 +349,5 @@
             if (plugins.contains(depr.name)) {
                 plugins.remove(depr.name);
-                PreferencesUtils.removeFromCollection(Config.getPref(), "plugins", depr.name);
+                PreferencesUtils.removeFromList(Config.getPref(), "plugins", depr.name);
                 removedPlugins.add(depr);
             }
@@ -403,5 +403,5 @@
                     Utils.escapeReservedCharactersHTML(unmaintained));
             if (confirmDisablePlugin(parent, msg, unmaintained)) {
-                PreferencesUtils.removeFromCollection(Config.getPref(), "plugins", unmaintained);
+                PreferencesUtils.removeFromList(Config.getPref(), "plugins", unmaintained);
                 plugins.remove(unmaintained);
             }
@@ -801,5 +801,5 @@
         }
         if (msg != null && confirmDisablePlugin(parent, msg, plugin.name)) {
-            PreferencesUtils.removeFromCollection(Config.getPref(), "plugins", plugin.name);
+            PreferencesUtils.removeFromList(Config.getPref(), "plugins", plugin.name);
         }
     }

Index: trunk/src/org/openstreetmap/josm/data/PreferencesUtils.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/PreferencesUtils.java	(revision 12893)
+++ trunk/src/org/openstreetmap/josm/data/PreferencesUtils.java	(revision 12894)
@@ -528,12 +528,11 @@
 
     /**
      * Removes a value from a given String collection
      * @param prefs the preferences
-     * @param key The preference key the collection is stored with
-     * @param value The value that should be removed in the collection
-     * @see #getList(String)
-     * @since 12891
-     */
-    public static void removeFromCollection(IPreferences prefs, String key, String value) {
+     * @param key The preference key the list is stored with
+     * @param value The value that should be removed in the list
+     * @since 12894
+     */
+    public static void removeFromList(IPreferences prefs, String key, String value) {
         synchronized (prefs) {
             List<String> a = new ArrayList<>(prefs.getList(key, Collections.<String>emptyList()));
@@ -544,5 +543,5 @@
 
     /**
      * Saves at most {@code maxsize} items of collection {@code val}.
      * @param prefs the preferences
      * @param key key
@@ -550,7 +549,7 @@
      * @param val value
      * @return {@code true}, if something has changed (i.e. value is different than before)
-     * @since 12891
-     */
-    public static boolean putCollectionBounded(IPreferences prefs, String key, int maxsize, Collection<String> val) {
+     * @since 12894
+     */
+    public static boolean putListBounded(IPreferences prefs, String key, int maxsize, List<String> val) {
         List<String> newCollection = new ArrayList<>(Math.min(maxsize, val.size()));
         for (String i : val) {
@@ -528,12 +528,11 @@
 
     /**
-     * Removes a value from a given String collection
+     * Removes a value from a given String list
      * @param prefs the preferences
@@ -544,5 +543,5 @@
 
     /**
-     * Saves at most {@code maxsize} items of collection {@code val}.
+     * Saves at most {@code maxsize} items of list {@code val}.
      * @param prefs the preferences
      * @param key key